@@ -7,7 +7,6 @@
  *
  */
 
-use heck::TitleCase;
 use rand::Rng;
 use std::mem::swap;
 
@@ -40,8 +39,9 @@ pub fn password(words: Vec<String>, mut s1: String, mut s2: String) -> String {
 pub fn choose_words(words: &mut Vec<String>, n: usize) -> Vec<String> {
     let mut rng = rand::thread_rng();
     let mut chosen: Vec<String> = Vec::with_capacity(n);
+    //words = words.into_iter().map(|x| x.trim().to_string()).collect::<Vec<String>>();
     chosen.resize_with(n, || {
-        words.remove(rng.gen_range(0..words.len())).to_title_case()
+        words.remove(rng.gen_range(0..words.len()))
     });
     chosen
 }
